@@ -84,7 +84,7 @@ inline double giac_log(double d){
 #include <cstring>
 #endif
 #include <iostream>
-#include <fstream>
+//#include <fstream>
 #include <map>
 
 #ifdef GNUWINCE
@@ -615,7 +615,7 @@ throw(std::runtime_error("Stopped by user interruption.")); \
     std::string _format_double_;
     std::string _autosimplify_;
     std::string _lastprog_name_;
-    std::string _currently_scanned_;
+    const char * _currently_scanned_;
 #ifndef NUMWORKS
     std::vector<logo_turtle> _turtle_stack_; 
 #endif
@@ -670,7 +670,7 @@ throw(std::runtime_error("Stopped by user interruption.")); \
 #endif
 
   const char * & last_evaled_function_name(GIAC_CONTEXT);
-  std::string & currently_scanned(GIAC_CONTEXT);
+  const char * & currently_scanned(GIAC_CONTEXT);
   const gen * & last_evaled_argptr(GIAC_CONTEXT);
 
   bool make_thread(const giac::gen & g,int level,const giac_callback & f,void * f_param,const context * contextptr);
@@ -797,6 +797,7 @@ throw(std::runtime_error("Stopped by user interruption.")); \
 
 #ifdef NUMWORKS
   logo_turtle & turtle();
+  std::vector<logo_turtle> & turtle_stack();
 #else
   logo_turtle & turtle(GIAC_CONTEXT);
   std::vector<logo_turtle> & turtle_stack(GIAC_CONTEXT);
